Crate typdiff

Crate typdiff 

Modules

diff
parse
render

Structs

DiffSpan
A span within a modified block, representing equal, deleted, or inserted text.

Enums

Block
A block-level element extracted from a Typst document.
BlockKind
The kind of block, used to determine if two blocks can be merged into a Modified result.
DiffResult
Result of diffing two documents at the block level.
SpanTag
Tag for a diff span.